@@ -2,18 +2,14 @@
 use derive_more::{From, Into};
 extern crate base64;
 use pythonize::{depythonize, pythonize};
-use solders_traits::{
-    handle_py_value_err, CommonMethods, PyBytesBincode, PyFromBytesBincode, RichcmpEqualityOnly,
-};
+use solders_primitives::{message::MessageHeader, pubkey::Pubkey, signature::Signature};
+use solders_traits::{handle_py_value_err, RichcmpEqualityOnly};
 use std::fmt::Display;
 use std::str::FromStr;
 
 use crate::{
     account_decoder::UiTokenAmount,
     commitment_config::CommitmentConfig,
-    message::MessageHeader,
-    pubkey::Pubkey,
-    signature::Signature,
     tmp_transaction_status::{
         EncodedConfirmedTransactionWithStatusMeta as EncodedConfirmedTransactionWithStatusMetaOriginal,
         EncodedTransaction as EncodedTransactionOriginal,
@@ -35,7 +31,6 @@ use crate::{
         UiTransactionStatusMeta as UiTransactionStatusMetaOriginal,
         UiTransactionTokenBalance as UiTransactionTokenBalanceOriginal,
     },
-    transaction::{TransactionVersion, VersionedTransaction},
     SolderHash,
 };
 use pyo3::{
@@ -50,7 +45,8 @@ use solana_sdk::{
     slot_history::Slot, transaction::TransactionError as TransactionErrorOriginal,
     transaction_context::TransactionReturnData as TransactionReturnDataOriginal,
 };
-use solders_macros::{common_methods, enum_original_mapping, richcmp_eq_only};
+use solders_macros::{common_methods, enum_original_mapping, richcmp_eq_only, EnumIntoPy};
+use solders_primitives::transaction::{TransactionVersion, VersionedTransaction};
 
 macro_rules! transaction_status_boilerplate {
     ($name:ident) => {
@@ -62,7 +58,7 @@ macro_rules! transaction_status_boilerplate {
         }
         solders_traits::pybytes_general_via_bincode!($name);
         solders_traits::py_from_bytes_general_via_bincode!($name);
-        impl<'a> CommonMethods<'a> for $name {}
+        solders_traits::common_methods_default!($name);
     };
 }
 
@@ -367,22 +363,13 @@ impl UiPartiallyDecodedInstruction {
     }
 }
 
-#[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize, FromPyObject)]
+#[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize, FromPyObject, EnumIntoPy)]
 #[serde(rename_all = "camelCase", untagged)]
 pub enum UiParsedInstruction {
     Parsed(ParsedInstruction),
     PartiallyDecoded(UiPartiallyDecodedInstruction),
 }
 
-impl IntoPy<PyObject> for UiParsedInstruction {
-    fn into_py(self, py: Python<'_>) -> PyObject {
-        match self {
-            Self::Parsed(m) => m.into_py(py),
-            Self::PartiallyDecoded(m) => m.into_py(py),
-        }
-    }
-}
-
 impl From<UiParsedInstruction> for UiParsedInstructionOriginal {
     fn from(ix: UiParsedInstruction) -> Self {
         match ix {
@@ -402,22 +389,13 @@ impl From<UiParsedInstructionOriginal> for UiParsedInstruction {
 }
 
 /// A duplicate representation of an Instruction for pretty JSON serialization
-#[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize, FromPyObject)]
+#[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize, FromPyObject, EnumIntoPy)]
 #[serde(rename_all = "camelCase", untagged)]
 pub enum UiInstruction {
     Compiled(UiCompiledInstruction),
     Parsed(UiParsedInstruction),
 }
 
-impl IntoPy<PyObject> for UiInstruction {
-    fn into_py(self, py: Python<'_>) -> PyObject {
-        match self {
-            Self::Compiled(m) => m.into_py(py),
-            Self::Parsed(m) => m.into_py(py),
-        }
-    }
-}
-
 impl From<UiInstruction> for UiInstructionOriginal {
     fn from(ix: UiInstruction) -> Self {
         match ix {
@@ -498,7 +476,7 @@ impl UiParsedMessage {
     }
 }
 
-#[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize, FromPyObject)]
+#[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize, FromPyObject, EnumIntoPy)]
 #[serde(rename_all = "camelCase", untagged)]
 pub enum UiMessage {
     Parsed(UiParsedMessage),
@@ -523,15 +501,6 @@ impl From<UiMessage> for UiMessageOriginal {
     }
 }
 
-impl IntoPy<PyObject> for UiMessage {
-    fn into_py(self, py: Python<'_>) -> PyObject {
-        match self {
-            Self::Parsed(p) => p.into_py(py),
-            Self::Raw(r) => r.into_py(py),
-        }
-    }
-}
-
 #[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize, From, Into)]
 #[pyclass(module = "solders.transaction_status", subclass)]
 pub struct UiTransaction(UiTransactionOriginal);
@@ -566,7 +535,7 @@ impl UiTransaction {
     }
 }
 
-#[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize, FromPyObject)]
+#[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize, FromPyObject, EnumIntoPy)]
 #[serde(rename_all = "camelCase", untagged)]
 pub enum EncodedVersionedTransaction {
     Binary(VersionedTransaction),
@@ -616,15 +585,6 @@ pub enum EncodedTransaction {
     Json(UiTransaction),
 }
 
-impl IntoPy<PyObject> for EncodedVersionedTransaction {
-    fn into_py(self, py: Python<'_>) -> PyObject {
-        match self {
-            Self::Binary(b) => b.into_py(py),
-            Self::Json(u) => u.into_py(py),
-        }
-    }
-}
-
 impl From<EncodedTransactionOriginal> for EncodedTransaction {
     fn from(e: EncodedTransactionOriginal) -> Self {
         match e {
@@ -1053,22 +1013,13 @@ pub enum InstructionErrorFieldless {
     MaxAccountsExceeded,
 }
 
-#[derive(FromPyObject, Clone, PartialEq, Eq, Serialize, Deserialize, Debug)]
+#[derive(FromPyObject, Clone, PartialEq, Eq, Serialize, Deserialize, Debug, EnumIntoPy)]
 pub enum InstructionErrorTagged {
     Custom(InstructionErrorCustom),
     BorshIoError(InstructionErrorBorshIO),
 }
 
-impl IntoPy<PyObject> for InstructionErrorTagged {
-    fn into_py(self, py: Python<'_>) -> PyObject {
-        match self {
-            Self::Custom(x) => x.into_py(py),
-            Self::BorshIoError(x) => x.into_py(py),
-        }
-    }
-}
-
-#[derive(FromPyObject, Clone, PartialEq, Eq, Serialize, Deserialize, Debug)]
+#[derive(FromPyObject, Clone, PartialEq, Eq, Serialize, Deserialize, Debug, EnumIntoPy)]
 #[serde(untagged)]
 pub enum InstructionErrorType {
     Fieldless(InstructionErrorFieldless),
@@ -1327,15 +1278,6 @@ impl From<InstructionErrorOriginal> for InstructionErrorType {
     }
 }
 
-impl IntoPy<PyObject> for InstructionErrorType {
-    fn into_py(self, py: Python<'_>) -> PyObject {
-        match self {
-            Self::Fieldless(f) => f.into_py(py),
-            Self::Tagged(t) => t.into_py(py),
-        }
-    }
-}
-
 #[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize, From, Into)]
 #[pyclass(module = "solders.transaction_status", subclass)]
 pub struct TransactionErrorInstructionError(pub (u8, InstructionErrorType));
@@ -1433,24 +1375,14 @@ pub enum TransactionErrorFieldless {
     WouldExceedAccountDataTotalLimit,
 }
 
-#[derive(FromPyObject, Clone, PartialEq, Eq, Serialize, Deserialize, Debug)]
+#[derive(FromPyObject, Clone, PartialEq, Eq, Serialize, Deserialize, Debug, EnumIntoPy)]
 pub enum TransactionErrorTypeTagged {
     InstructionError(TransactionErrorInstructionError),
     DuplicateInstruction(TransactionErrorDuplicateInstruction),
     InsufficientFundsForRent(TransactionErrorInsufficientFundsForRent),
 }
 
-impl IntoPy<PyObject> for TransactionErrorTypeTagged {
-    fn into_py(self, py: Python<'_>) -> PyObject {
-        match self {
-            Self::InstructionError(e) => e.into_py(py),
-            Self::DuplicateInstruction(d) => d.into_py(py),
-            Self::InsufficientFundsForRent(i) => i.into_py(py),
-        }
-    }
-}
-
-#[derive(FromPyObject, Clone, PartialEq, Eq, Serialize, Deserialize, Debug)]
+#[derive(FromPyObject, Clone, PartialEq, Eq, Serialize, Deserialize, Debug, EnumIntoPy)]
 #[serde(untagged)]
 pub enum TransactionErrorType {
     Fieldless(TransactionErrorFieldless),
@@ -1647,15 +1579,6 @@ impl From<TransactionErrorOriginal> for TransactionErrorType {
     }
 }
 
-impl IntoPy<PyObject> for TransactionErrorType {
-    fn into_py(self, py: Python<'_>) -> PyObject {
-        match self {
-            Self::Fieldless(f) => f.into_py(py),
-            Self::Tagged(t) => t.into_py(py),
-        }
-    }
-}
-
 #[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize, From, Into)]
 #[pyclass(module = "solders.transaction_status", subclass)]
 pub struct Reward(RewardOriginal);
